pub enum Direction {
Above,
Below,
Left,
Right,
}Expand description
Direction a new pane appears relative to its split origin.
Variants
Above
Above the originating pane (creates a Horizontal split — the
terminology mirrors tmux’s split-window -b -v).
Below
Below the originating pane (default for tmux’s C-b ").
Left
Left of the originating pane.
Right
Right of the originating pane (default for tmux’s C-b %).
Implementations
Sourceimpl Direction
impl Direction
Sourcepub const fn orientation(self) -> SplitOrientation
pub const fn orientation(self) -> SplitOrientation
The split orientation this direction creates. A new pane to the right introduces a vertical split (the cells of cells are arranged side by side); above/below introduces a horizontal split (stacked rows).