Module window

Module window 

Window — a named tab inside a session, holding a layout tree.

Structs

TearWindow
One window: a named tab that holds a binary-tree layout of panes. Windows are created/destroyed independently of their parent session and have their own active-pane focus.

Enums

WindowState
Window lifecycle states.